
/*
 * CTU Open Contest 2014
 * Problem solution: Lengthy Traveling Salesman
 *
 * Author: Zdenek Dvorak
 */

#include <stdio.h>
 
#define MAXN 10000
 
static int son[MAXN], brother[MAXN], size[MAXN];
static int n;
static int part[3][MAXN];
static int partsize[3];
 
static void
addexcept (int p, int a, int e)
{
  int s;
 
  if (a == e)
    return;
 
  part[p][partsize[p]++] = a;
  for (s = son[a]; s != -1; s = brother[s])
    addexcept (p, s, e);
}
 
static int
minpart (void)
{
  if (partsize[0] <= partsize[1] && partsize[0] <= partsize[2])
    return 0;
 
  if (partsize[1] <= partsize[2])
    return 1;
 
  return 2;
}
 
static void
swap (int *x, int *y)
{
  int t = *x;
  *x = *y;
  *y = t;
}
 
static int heads[MAXN + 1], next[MAXN];
 
static void
regist (int v, int s)
{
  next[v] = heads[s];
  heads[s] = v;
}
 
int main(void)
{
  int i, j, f;
  int a, b, c;
  const char *sep;
 
  while (scanf ("%d", &n) == 1)
    {
      if (n == 1)
	{
	  printf ("0\n");
	  continue;
	}
 
      for (i = 0; i < n; i++)
	{
	  son[i] = brother[i] = -1;
	  heads[i] = next[i] = -1;
	}
      heads[n] = -1;
 
      for (i = 1; i < n; i++)
	{
	  scanf ("%d", &f);
	  brother[i] = son[f];
	  son[f] = i;
	}
 
      for (i = n - 1; i >= 0; i--)
	{
	  size[i] = 1;
	  for (j = son[i]; j != -1; j = brother[j])
	    size[i] += size[j];
	  if (2 * size[i] >= n)
	    break;
	}
 
      for (j = 0; j < 3; j++)
	partsize[j] = 0;
 
      regist (0, n - size[i]);
      for (j = son[i]; j != -1; j = brother[j])
	regist (j, size[j]);
 
      for (j = n; j > 0; j--)
	for (f = heads[j]; f != -1; f = next[f])
	  addexcept (minpart (), f, i);
      f = minpart ();
      part[f][partsize[f]++] = i;
 
      a = 0; b = 1; c = 2;
      if (partsize[a] > partsize[b])
	swap (&a, &b);
      if (partsize[b] > partsize[c])
	swap (&b, &c);
      if (partsize[a] > partsize[b])
	swap (&a, &b);
 
      sep = "";
      while (partsize[a] < partsize[b])
	{
	  printf ("%s%d", sep, part[b][--partsize[b]]);
          sep = " ";
	  printf (" %d", part[c][--partsize[c]]);
	}
      while (partsize[b] < partsize[c])
	{
	  printf ("%s%d", sep, part[b][--partsize[b]]);
          sep = " ";
	  printf (" %d", part[c][--partsize[c]]);
	  printf (" %d", part[a][--partsize[a]]);
	  printf (" %d", part[c][--partsize[c]]);
	}
      while (partsize[a] > 0)
	{
	  printf ("%s%d", sep, part[b][--partsize[b]]);
          sep = " ";
	  printf (" %d", part[a][--partsize[a]]);
	  printf (" %d", part[c][--partsize[c]]);
	}
      printf ("\n");
    }
  return 0;
}
