import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;


/**
 * CTU Open Contest 2014
 * Problem solution: Lengthy Traveling Salesman
 * 
 * This solution intentionally uses collections and Integers (instead of ints)
 * to make sure that such an approach is fast enough to be accepted.
 * 
 * @author Martin Kacer
 */
public class lengthy {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	boolean hasNextToken() throws Exception {
		while (!st.hasMoreTokens()) {
			String line = input.readLine();
			if (line == null) return false;
			st = new StringTokenizer(line);
		}
		return true;
	}
	String nextToken() throws Exception {
		return (!hasNextToken()) ? null : st.nextToken();
	}
	int nextInt() throws Exception {
		String s = nextToken();
		return (s == null) ? -1 : Integer.parseInt(s);
	}
	public static void main(String[] args) throws Exception {
		lengthy instance = new lengthy();
		while (instance.hasNextToken())
			instance.run();
	}
	
	int root;
	int[] subCount;
	List<Integer>[] children;
	@SuppressWarnings("unchecked") List<Integer>[] initList(int n) {
		return new List[n];
	}	
	void addChild(int par, int chld) {
		if (children[par] == null) children[par] = new ArrayList<Integer>();
		children[par].add(Integer.valueOf(chld));
	}
	Integer removeLast(List<Integer> lst) { return lst.remove(lst.size()-1); }
	
	int findRoot(int idx) {
		if (children[idx] == null) return 1;
		boolean found = false;
		for (Iterator<Integer> it = children[idx].iterator(); it.hasNext(); ) {
			int ch = it.next().intValue();
			int sub = findRoot(ch);
			if (sub*2 >= children.length) {
				addChild(ch, idx); // reverse this edge
				it.remove(); // not constant but called at most once for each node
				found = true;
			}
			subCount[idx] += sub;
		}
		if (++subCount[idx] * 2 >= children.length && !found) root = idx;
		return subCount[idx];
	}
	
	void collectChildren(Integer idx, List<Integer> add) {
		add.add(idx);
		if (children[idx.intValue()] != null) for (Integer ch : children[idx.intValue()])
			collectChildren(ch, add);
	}

	void run() throws Exception {
		children = initList(nextInt()); subCount = new int[children.length];
		for (int i = 1; i < children.length; ++i) addChild(nextInt(), i);
		if (children.length == 1) { System.out.println("0"); return; }
		if (children.length == 2) { System.out.println("0 1"); return; }
		findRoot(root = 0);
		List<Integer>[] subs = initList(children[root].size()+2);
		for (int i = 0; i < children[root].size(); ++i) {
			Integer ch = children[root].get(i);
			subs[i] = new ArrayList<Integer>(subCount[ch.intValue()]);
			collectChildren(ch, subs[i]);
		}
		subs[subs.length-2] = new ArrayList<Integer>(1); subs[subs.length-2].add(Integer.valueOf(root));
		subs[subs.length-1] = new ArrayList<Integer>(0); // to avoid some special cases
		Arrays.sort(subs, new Comparator<List<Integer>>() {
			public int compare(List<Integer> o1, List<Integer> o2) {
				return o2.size() - o1.size();
			}
		});
		int second, smaller = 2, cnt = children.length;
		while (subs[smaller].size() == subs[1].size()) ++smaller;
		second = smaller-1;
		// first, interleave the largest subtree with others until it has the same size
		while (subs[0].size() > subs[1].size()) {
			System.out.print(removeLast(subs[0]) + " "); --cnt;
			System.out.print(removeLast(subs[second]) + " "); --cnt;
			if (--second == 0) {
				while (subs[smaller].size() == subs[1].size()) ++smaller;
				second = smaller-1;
			}
		}
		for (int num = subs[0].size(); num > 0; --num) {
			for (int i = 0; i < subs.length && subs[i].size() == num; ++i) {
				System.out.print(subs[i].remove(subs[i].size()-1)); --cnt;
				if (cnt > 0) System.out.print(" ");
			}
		}
		System.out.println();
	}
}
