
/*
 * CTU Open Contest 2014
 * Problem solution: Self Intersection
 *
 * Author: Michal "Mimino" Danilak
 */

#include <cstdio>
#include <algorithm>
using namespace std;
 
const int MAX = 1000007, dx[] = { 0, 1, 0, -1 }, dy[] = { 1, 0, -1, 0 };
int N, a[MAX];
 
struct Point
{
	int x, y;
	Point(int _x = 0, int _y = 0) :
		x(_x), y(_y) {}
} points[MAX];
 
// true, if intervals [a,b] and [c,d] have non-empty intersection
bool overlap(int a, int b, int c, int d)
{
	if (a > b) swap(a, b);
	if (c > d) swap(c, d);
	return !(b < c || d < a);
}
 
// true if line segments [a1,a2] and [b1,b2] have non-empty intersection
bool intersect(Point a1, Point a2, Point b1, Point b2)
{
	bool is_vertical_a = (a1.x == a2.x), is_vertical_b = (b1.x == b2.x);
	if (is_vertical_a && is_vertical_b)
		return a1.x == b1.x && overlap(a1.y, a2.y, b1.y, b2.y);
	if (!is_vertical_a && !is_vertical_b)
		return a1.y == b1.y && overlap(a1.x, a2.x, b1.x, b2.x);
	// make a horizontal and b vertical
	if (is_vertical_a)
	{
		swap(a1, b1);
		swap(a2, b2);
	}
	return !(
		max(a1.x, a2.x) < b1.x ||
		min(a1.x, a2.x) > b1.x ||
		max(b1.y, b2.y) < a1.y ||
		min(b1.y, b2.y) > a1.y);
}
 
int solve()
{
	int x = 0, y = 0;
	for (int i = 0; i < N; ++i)
	{
		x += dx[i & 3] * a[i];
		y += dy[i & 3] * a[i];
		points[i + 1].x = x;
		points[i + 1].y = y;
		for (int j = max(0, i - 8); j < i - 2; ++j)
		if (intersect(points[j], points[j + 1], points[i], points[i + 1]))
			return i;
	}
	return -1;
}
 
int main()
{
	while (scanf("%d", &N) == 1)
	{
		for (int i = 0; i < N; ++i)
			scanf("%d", a + i);
		int result = solve();
		if (result == -1)
			printf("OK\n");
		else
			printf("%d\n", result);
	}
 
	return 0;
}
