import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

/**
 * CTU Open Contest 2014
 * Problem solution: Self Intersection
 * 
 * <pre>
 *     +left     +right
 *     <---- x=0 ----->
 *  
 *    left  right0   right
 *    |     |        |
 *    v     v        v
 * 
 *    +--------------+      <-- top    ^ +top
 *    |              |                 |
 *    |   XXX        |                 y=0
 *    |   X |        |                 |
 *    +-----+        |      <-- bot0   |
 *                   |                 v +bot
 *         <=========*      <-- bot
 *         (* = current pos)
 * </pre>
 * 
 * @author Martin Kacer
 */
public class self {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	boolean hasNextToken() throws Exception {
		while (!st.hasMoreTokens()) {
			String line = input.readLine();
			if (line == null) return false;
			st = new StringTokenizer(line);
		}
		return true;
	}
	String nextToken() throws Exception {
		return (!hasNextToken()) ? null : st.nextToken();
	}
	int nextInt() throws Exception {
		String s = nextToken();
		return (s == null) ? -1 : Integer.parseInt(s);
	}
	public static void main(String[] args) throws Exception {
		self instance = new self();
		while (instance.hasNextToken())
			instance.run();
	}

	void run() throws Exception {
		int n = nextInt(), norig = n;
		int right0 = 0, bot0 = 0, left = 0, top = 0, right = 0, bot = 0;
		while (n-- > 0) { // out-bound spiral (see picture above)
			int nxtleft = nextInt() - right;
			if (nxtleft < -right0) { left = nxtleft; break; }
			else if (nxtleft <= left) { left = nxtleft; top = -bot0; break; }
			right0 = bot0; bot0 = left; left = top; top = right; right = bot; bot = nxtleft;
		}
		while (n-- > 0) { // in-bound spiral (inside a rectangle)
			int nxttop = nextInt() - bot;
			if (nxttop >= top) break;
			top = right; right = bot; bot = left; left = nxttop;
		}
		System.out.println((n < 0) ? "OK" : String.valueOf(norig-n-1));
		while (n-- > 0) nextInt();
	}
}
