

/*
 * CTU Open Contest 2014
 * Problem solution: Karel the Robot
 * Operational complexity: O(N^2)
 *
 * Author: Michal "Mimino" Danilak
 */

#include <cstdio>
#include <vector>
#include <algorithm>
using namespace std;
 
const int INF = 1<<29;
 
struct Point
{
	int x, y;
	Point() {}
	Point(int _x, int _y): x(_x), y(_y) {}
 
	bool operator<(const Point & p) const 
		{ return x < p.x || (x == p.x && y < p.y); }
 
	bool operator==(const Point & p) const
		{ return x == p.x && y == p.y; }
 
	Point operator-(const Point & p) const 
		{ return Point(x-p.x, y-p.y); }
};
 
struct Line
{
	Point p1, p2;
	bool active;
	Line() {}
	Line(int _x1, int _y1, int _x2, int _y2): p1(_x1, _y1), p2(_x2, _y2), active(true)
		{ if (p2 < p1) swap(p1, p2); }
 
	bool operator<(const Line & l) const 
		{ return p1 < l.p1 || (p1 == l.p1 && p2 < l.p2); }
 
	bool operator==(const Line & l) const
		{ return p1 == l.p1 && p2 == l.p2; }
};
 
int cross_product(const Point & p1, const Point & p2) 
{ 
	return p1.x * p2.y - p1.y * p2.x; 
}
 
int direction(const Point & p1, const Point & p2, const Point & p3)
{
	return cross_product(p3-p1, p2-p1);
}
 
bool on_segment(const Point & s1, const Point & s2, const Point & p)
{
	return min(s1.x, s2.x) <= p.x && p.x <= max(s1.x, s2.x) && min(s1.y, s2.y) <= p.y && p.y <= max(s1.y, s2.y); 
}
 
bool overlap(const Line & l1, const Line & l2)
{
	return direction(l1.p1, l1.p2, l2.p1) == 0 &&
		direction(l1.p1, l1.p2, l2.p2) == 0 &&
		(on_segment(l1.p1, l1.p2, l2.p1) || on_segment(l1.p1, l1.p2, l2.p2)
			|| on_segment(l2.p1, l2.p2, l1.p1) || on_segment(l2.p1, l2.p2, l1.p2));
}
 
void read(int T, vector<Line> & v)
{
	char instr;
	int x = 0, y = 0, dx, dy, mx = INF, my = INF;
	while (T--)
	{
		scanf(" %c %d %d", &instr, &dx, &dy);
		if (instr == 'M')
		{
			x += dx;
			y += dy;
		}
		else
		{
			v.push_back(Line(x, y, x+dx, y+dy));
			mx = min(mx, min(x, x+dx));
			my = min(my, min(y, y+dy));
			x += dx;
			y += dy;
		}
	}
	// normalize the shift of the images
	for (int i = 0; i < v.size(); ++i)
	{
		v[i].p1.x -= mx;
		v[i].p1.y -= my;
		v[i].p2.x -= mx;
		v[i].p2.y -= my;
	}
	// merge overlapping lines
	for (int i = 0; i < v.size(); ++i)
		for (int j = 0; j < v.size(); ++j)
		{
			if (i==j || !v[j].active) continue;
			if (overlap(v[i], v[j]))
			{
				v[j].p1 = min(v[i].p1, v[j].p1);
				v[j].p2 = max(v[i].p2, v[j].p2);
				v[i].active = false;
				break;
			}
		}
	// remove inactive lines
	for (int i = 0; i < v.size(); ++i)
		if (!v[i].active)
		{
			swap(v[i--], v.back());
			v.pop_back();
		}
	// normalize
	sort(v.begin(), v.end());
}
 
int main()
{
	int T;
	while (scanf("%d", &T) == 1)
	{
		vector<Line> v1, v2;
		read(T, v1);
		scanf("%d", &T);
		read(T, v2);
		printf("%s\n", v1==v2 ? "YES" : "NO");
	}
 
	return 0;
}
