import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

/**
 * CTU Open Contest 2014
 * Problem solution: Direct Visibility
 * 
 * @author Martin Kacer
 */
public class visible {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	boolean hasNextToken() throws Exception {
		while (!st.hasMoreTokens()) {
			String line = input.readLine();
			if (line == null) return false;
			st = new StringTokenizer(line);
		}
		return true;
	}
	String nextToken() throws Exception {
		return (!hasNextToken()) ? null : st.nextToken();
	}
	int nextInt() throws Exception {
		String s = nextToken();
		return (s == null) ? -1 : Integer.parseInt(s);
	}
	public static void main(String[] args) throws Exception {
		visible instance = new visible();
		int prob = instance.nextInt();
		while (prob-->0)
			instance.run();
	}

	int[][] map, mapt, dist;
	boolean[][] vis;
	int[] qx, qy;
	int qb, qe;
	
	/**
	 * For a line segment (x1,y1)-(x2,y2) and a given xx,
	 * calculate the corresponding yy of the point on the line.
	 * Preconditions: x1<=xx<=x2 and abs(x1-x2)>=abs(y1-y2)
	 * The result is copied into yyout[0] (rounded down) and yyout[1] (rounded up).
	 */
	void calcInterPoint(int x1, int x2, int y1, int y2, int xx, int[] yyout) {
		int xd = x2-x1, yd = y2-y1, xxd = xx-x1;
		yyout[0] = yyout[1] = y1 + (xxd * yd) / xd;
		if ((xxd * yd) % xd != 0) {
			if (yd < 0) --yyout[0]; else ++yyout[1];
		}
	}
	
	boolean isVisible(int x1, int y1, int x2, int y2, int[][] mm) {
		if (x1 == x2 && y1 == y2) return true;
		if (Math.abs(x1-x2) < Math.abs(y1-y2)) return isVisible(y1, x1, y2, x2, mapt);
		if (x1 > x2) return isVisible(x2, y2, x1, y1, mm);
		int xx1 = x1*2 + 1, yy1 = y1*2 + 1, xx2 = x2*2 + 1, yy2 = y2*2 + 1;
		int zz1 = mm[x1][y1]*2 + 1, zz2 = mm[x2][y2]*2 + 1;
		int[] yy = new int[2], zz = new int[2];
		for (int xx = xx1 + 1; xx < xx2; xx += 2) {
			calcInterPoint(xx1, xx2, yy1, yy2, xx, yy);
			calcInterPoint(xx1, xx2, zz1, zz2, xx, zz);
			int xn = xx/2, xp = xn-1, yn = yy[0]/2, yp = yn;
			if (yy[0] == yy[1] && (yy[0]%2==0)) { if (y2>y1) --yp; else --yn; }
			if (mm[xp][yp] > zz[0]/2 || mm[xn][yn] > zz[0]/2) return false;
		}
		return true;
	}
	
	void enqueue(int x, int y, int h, int d) {
		if (!vis[x][y] || dist[x][y] > 0) return;
		if (map[x][y] < h-3 || map[x][y] > h+1) return;
		dist[x][y] = d+1; qx[qe] = x; qy[qe++] = y;
	}
	
	void run() throws Exception {
		int p = nextInt(), q = nextInt();
		map = new int[p][q]; mapt = new int[q][p];
		dist = new int[p][q]; vis = new boolean[p][q];
		for (int i = 0; i < p; ++i) for (int j = 0; j < q; ++j)
			map[i][j] = mapt[j][i] = nextInt();
		int r1 = nextInt()-1, c1 = nextInt()-1, r2 = nextInt()-1, c2 = nextInt()-1;
		for (int i = 0; i < p; ++i) for (int j = 0; j < q; ++j)
			vis[i][j] = isVisible(r1, c1, i, j, map) || isVisible(r2, c2, i, j, map);
		qx = new int[p*q]; qy = new int[p*q]; qb = qe = 0;
		enqueue(r1, c1, map[r1][c1], 0);
		while (qb < qe && dist[r2][c2] == 0) {
			int x = qx[qb], y = qy[qb++], h = map[x][y], d = dist[x][y];
			if (x > 0) enqueue(x-1, y, h, d);
			if (x+1 < p) enqueue(x+1, y, h, d);
			if (y > 0) enqueue(x, y-1, h, d);
			if (y+1 < q) enqueue(x, y+1, h, d);
		}
		System.out.println((dist[r2][c2] == 0) ? "Mission impossible!"
				: "The shortest path is "+(dist[r2][c2]-1)+" steps long.");
	}
}
